/*
** Copyright (C) 2006-2015 by Carnegie Mellon University.
**
** @OPENSOURCE_HEADER_START@
**
** Use of the SILK system and related source code is subject to the terms
** of the following licenses:
**
** GNU General Public License (GPL) Rights pursuant to Version 2, June 1991
** Government Purpose License Rights (GPLR) pursuant to DFARS 252.227.7013
**
** NO WARRANTY
**
** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
** DELIVERABLES UNDER THIS LICENSE.
**
** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
** Mellon University, its trustees, officers, employees, and agents from
** all claims or demands made against them (and any related losses,
** expenses, or attorney's fees) arising out of, or relating to Licensee's
** and/or its sub licensees' negligent use or willful misuse of or
** negligent conduct or willful misconduct regarding the Software,
** facilities, or other rights or assistance granted by Carnegie Mellon
** University under this License, including, but not limited to, any
** claims of product liability, personal injury, death, damage to
** property, or violation of any laws or regulations.
**
** Carnegie Mellon University Software Engineering Institute authored
** documents are sponsored by the U.S. Department of Defense under
** Contract FA8721-05-C-0003. Carnegie Mellon University retains
** copyrights in all material produced under this contract. The U.S.
** Government retains a non-exclusive, royalty-free license to publish or
** reproduce these documents, or allow others to do so, for U.S.
** Government purposes only pursuant to the copyright license under the
** contract clause at 252.227.7013.
**
** @OPENSOURCE_HEADER_END@
*/

/*
**  sksite.h
**
**    An interface to site-specific settings.
**
*/
#ifndef _SKSITE_H
#define _SKSITE_H
#ifdef __cplusplus
extern "C" {
#endif

#include <silk-ipset/silk-ipset.h>

RCSIDENTVAR(rcsID_SKSITE_H, "$SiLK: sksite.h a1b50424e5ad 2015-09-30 17:56:00Z mthomas $");


/**
 *  @file
 *
 *    The interface to site-specific settings, many of which are
 *    determined by the silk.conf file.
 *
 *    This file is part of libskipset.
 */


/* Special compression method values */
#define SK_COMPMETHOD_DEFAULT 255
#define SK_COMPMETHOD_BEST    254

/* The available compression methods */
#define SK_COMPMETHOD_NONE      0
#define SK_COMPMETHOD_ZLIB      1
#define SK_COMPMETHOD_LZO1X     2
/* when you add a compression method, add it to the following array */

#ifdef SKSITE_SOURCE
static const char *skCompressionMethods[] = {
    "none",
    "zlib",
    "lzo1x",
    ""
};
#endif /* SKSITE_SOURCE */


/* define various output file formats here that we write to disk */

#define FT_IPSET            0x1D
/* When you add new types here; add the name to the array below. */


/*
 *   This header is included by sksite.c after declaring
 *   SKSITE_SOURCE.  Users should use the function
 *   calls from sksite.h to access these strings values.
 */

#ifdef SKSITE_SOURCE
static const char *fileOutputFormats[] = {
    /* 0x00 */  "FT_RESERVED_00",
    /* 0x01 */  "FT_RESERVED_01",
    /* 0x02 */  "FT_RESERVED_02",
    /* 0x03 */  "FT_RESERVED_03",
    /* 0x04 */  "FT_RESERVED_04",
    /* 0x05 */  "FT_RESERVED_05",
    /* 0x06 */  "FT_RESERVED_06",
    /* 0x07 */  "FT_RESERVED_07",
    /* 0x08 */  "FT_RESERVED_08",
    /* 0x09 */  "FT_RESERVED_09",
    /* 0x0A */  "FT_RESERVED_0A",
    /* 0x0B */  "FT_RESERVED_0B",
    /* 0x0C */  "FT_RESERVED_0C",
    /* 0x0D */  "FT_RESERVED_0D",
    /* 0x0E */  "FT_RESERVED_0E",
    /* 0x0F */  "FT_RESERVED_0F",
    /* 0X10 */  "FT_RESERVED_10",
    /* 0X11 */  "FT_RESERVED_11",
    /* 0X12 */  "FT_RESERVED_12",
    /* 0X13 */  "FT_RESERVED_13",
    /* 0X14 */  "FT_RESERVED_14",
    /* 0X15 */  "FT_RESERVED_15",
    /* 0x16 */  "FT_RESERVED_16",
    /* 0x17 */  "FT_RESERVED_17",
    /* 0x18 */  "FT_RESERVED_18",
    /* 0x19 */  "FT_RESERVED_19",
    /* 0x1A */  "FT_RESERVED_1A",
    /* 0x1B */  "FT_RESERVED_1B",
    /* 0x1C */  "FT_RESERVED_1C",
    /* 0x1D */  "FT_IPSET",
    /* 0x1E */  "FT_RESERVED_1E",
    /* 0x1F */  "FT_RESERVED_1F",
    /* 0x20 */  "FT_RESERVED_20",
    /* 0x21 */  "FT_RESERVED_21",
    /* 0x22 */  "FT_RESERVED_22",
    /* 0x23 */  "FT_RESERVED_23",
    /* 0x24 */  "FT_RESERVED_24",
    /* 0x25 */  "FT_RESERVED_25",
    ""
};
#endif /* SKSITE_SOURCE */


/** Configuration and Initialization **********************************/

/**
 *    Initialize everything related to the site *except* the sensor
 *    configuration from the config file.  The parameter 'levels' is
 *    currently unused.
 *
 *    Application writers do not need to call this function as it is
 *    called by skAppRegister().
 */
int
sksiteInitialize(
    int                 levels);


/**
 *    Destroy all the data structures and deallocate all memory
 *    associated with the site.
 *
 *    Application writers do not need to call this function as it is
 *    called by skAppUnregister().
 */
void
sksiteTeardown(
    void);


/** File Formats ******************************************************/

/**
 *    Get the name of the file format with the given ID into the given
 *    buffer of size buffer_size.  If the name is longer than
 *    buffer_size, the value returns is truncated with a '\0' in the
 *    final position.
 *
 *    Returns the number of characters that would have been written if
 *    the buffer had been long enough.
 */
int
sksiteFileformatGetName(
    char               *buffer,
    size_t              buffer_size,
    sk_file_format_t    format_id);

/**
 *    Return 1 if 'format_id' is a valid file output format, or 0 if
 *    it is not.
 */
int
sksiteFileformatIsValid(
    sk_file_format_t    format_id);

/**
 *    Returns the file output format associated with the name.  If the
 *    name is unknown, will return an invalid file format.
 */
sk_file_format_t
sksiteFileformatFromName(
    const char         *name);


/*** Compression Methods ***********************************************/

/**    values returned by sksiteCompmethodCheck() */
#define SK_COMPMETHOD_IS_AVAIL  6
#define SK_COMPMETHOD_IS_VALID  2
#define SK_COMPMETHOD_IS_KNOWN  1

/**
 *    Check whether a compression method is valid and/or available.
 *
 *    If the compression method 'comp_method' is completely
 *    unrecognized, return 0.
 *
 *    Return SK_COMPMETHOD_IS_KNOWN when 'comp_method' is an
 *    "undecided" value (i.e., SK_COMPMETHOD_DEFAULT or
 *    SK_COMPMETHOD_BEST).  These compression methods should be
 *    considered valid for writing, as they will be converted to an
 *    appropriate type once the stream they are connected to is
 *    opened.
 *
 *    Return SK_COMPMETHOD_IS_VALID when 'comp_method' contains a
 *    known value other than an "undecided" value, but the compression
 *    method relies on an external library that is not part of this
 *    build of SiLK.
 *
 *    Return SK_COMPMETHOD_IS_AVAIL when 'comp_method' is a known
 *    value whose library is available.  These compression methods are
 *    valid for reading or for writing.
 *
 *    To determine whether 'comp_method' is valid for read, mask the
 *    output by 4.  To determine whether 'comp_method' is valid for
 *    write, mask the output of this function by 5. To determine
 *    whether 'comp_method' is an actual compression method (that is,
 *    not an "undecided" value), mask the output by 2.
 */
int
sksiteCompmethodCheck(
    sk_compmethod_t     comp_method);

/**
 *    Return the generically "best" compression method from all those
 *    that are available.
 */
sk_compmethod_t
sksiteCompmethodGetBest(
    void);

/**
 *    Return the default compression method.
 */
sk_compmethod_t
sksiteCompmethodGetDefault(
    void);

/**
 *    Given the compress method 'comp_method', write the name of that
 *    method into 'out_buffer' whose length is 'bufsize'.  The
 *    function returns a pointer to 'out_buffer', or NULL for an
 *    invalid compression method.
 */
int
sksiteCompmethodGetName(
    char               *buffer,
    size_t              buffer_size,
    sk_compmethod_t     comp_method);

/**
 *    Sets the default compression method.  Returns 0 on success, -1
 *    if the method is not available.
 */
int
sksiteCompmethodSetDefault(
    sk_compmethod_t     compression_method);

/**
 *    Add an option that will allow the user to set the compression
 *    method of binary output files.  After skOptionsParse()
 *    sucessfully returns, the variable pointed to by
 *    'compression_method' will contain the compression method to use.
 *
 *    If the user does not exercise the compression-method option,
 *    'compression_method' will be set to the default compression
 *    method.
 */
int
sksiteCompmethodOptionsRegister(
    sk_compmethod_t    *compression_method);

/**
 *    Include the compression method option in the list of options for
 *    --help output.
 */
void
sksiteCompmethodOptionsUsage(
    FILE               *fh);


#ifdef __cplusplus
}
#endif
#endif /* _SKSITE_H */

/*
** Local Variables:
** mode:c
** indent-tabs-mode:nil
** c-basic-offset:4
** End:
*/
